==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/OUTPUTCALCULATIONTYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour OUTPUTCALCULATIONTYPE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="OUTPUTCALCULATIONTYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTPUTCALCULATIONTYPECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OUTPUTCALCULATIONTYPE_Type", propOrder = {
    "outputcalculationtypecode",
    "description"
})
public class OUTPUTCALCULATIONTYPE_Type {

    @XmlElement(name = "OUTPUTCALCULATIONTYPECODE", required = true, defaultValue = "MANL")
    protected String outputcalculationtypecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété outputcalculationtypecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTPUTCALCULATIONTYPECODE() {
        return outputcalculationtypecode;
    }

    /**
     * Définit la valeur de la propriété outputcalculationtypecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTPUTCALCULATIONTYPECODE(String value) {
        this.outputcalculationtypecode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/OUTPUTCALCULATIONTYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OUTPUTCALCULATIONTYPE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OUTPUTCALCULATIONTYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTPUTCALCULATIONTYPECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OUTPUTCALCULATIONTYPE_Type", propOrder = {
    "outputcalculationtypecode",
    "description"
})
public class OUTPUTCALCULATIONTYPE_Type {

    @XmlElement(name = "OUTPUTCALCULATIONTYPECODE", required = true, defaultValue = "MANL")
    protected String outputcalculationtypecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the outputcalculationtypecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTPUTCALCULATIONTYPECODE() {
        return outputcalculationtypecode;
    }

    /**
     * Sets the value of the outputcalculationtypecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTPUTCALCULATIONTYPECODE(String value) {
        this.outputcalculationtypecode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
